@@ -6,6 +6,7 @@ import (
 	"errors"
 	"os"
 	"strings"
+	"syscall"
 	"time"
 
 	"github.com/shirou/gopsutil/v3/host"
@@ -123,3 +124,36 @@ func (env *ShellEnvironment) WifiNetwork() (*WifiInfo, error) {
 func (env *ShellEnvironment) LookWinAppPath(file string) (string, error) {
 	return "", errors.New("not relevant")
 }
+
+func (env *ShellEnvironment) DirIsWritable(path string) bool {
+	defer env.Trace(time.Now(), "DirIsWritable")
+	info, err := os.Stat(path)
+	if err != nil {
+		env.Log(Error, "DirIsWritable", err.Error())
+		return false
+	}
+
+	if !info.IsDir() {
+		env.Log(Error, "DirIsWritable", "Path isn't a directory")
+		return false
+	}
+
+	// Check if the user bit is enabled in file permission
+	if info.Mode().Perm()&(1<<(uint(7))) == 0 {
+		env.Log(Error, "DirIsWritable", "Write permission bit is not set on this file for user")
+		return false
+	}
+
+	var stat syscall.Stat_t
+	if err = syscall.Stat(path, &stat); err != nil {
+		env.Log(Error, "DirIsWritable", err.Error())
+		return false
+	}
+
+	if uint32(os.Geteuid()) != stat.Uid {
+		env.Log(Error, "DirIsWritable", "User doesn't have permission to write to this directory")
+		return false
+	}
+
+	return true
+}
