@@ -67,6 +67,7 @@ module.exports = {
         "segments/executiontime",
         "segments/exit",
         "segments/flutter",
+        "segments/fossil",
         "segments/git",
         "segments/poshgit",
         "segments/golang",
@@ -97,6 +98,7 @@ module.exports = {
         "segments/shell",
         "segments/spotify",
         "segments/strava",
+        "segments/svn",
         "segments/swift",
         "segments/sysinfo",
         "segments/terraform",
